#[macro_use]
extern crate rocket;
pub mod auth;
pub mod error;
pub mod home;
pub mod response;
